@@ -1,6 +1,6 @@
 package MusicBrainz::Queries;
 
-# $Id: Queries.pm,v 1.6 2003/04/17 19:13:09 sander Exp $
+# $Id: Queries.pm,v 1.10 2005/12/16 04:57:39 robert Exp $
 
 use 5.006_001; 
 use strict;
@@ -25,10 +25,12 @@ our %EXPORT_TAGS = ( 'all' => [ qw(
 	MBE_AlbumGetAlbumName
 	MBE_AlbumGetAlbumStatus
 	MBE_AlbumGetAlbumType
+	MBE_AlbumGetAmazonAsin
 	MBE_AlbumGetArtistId
 	MBE_AlbumGetArtistName
 	MBE_AlbumGetArtistSortName
 	MBE_AlbumGetNumCdindexIds
+	MBE_AlbumGetNumReleaseDates
 	MBE_AlbumGetNumTracks
 	MBE_AlbumGetTrackDuration
 	MBE_AlbumGetTrackId
@@ -49,18 +51,24 @@ our %EXPORT_TAGS = ( 'all' => [ qw(
 	MBE_GetNumTracks
 	MBE_GetNumTrmids
 	MBE_GetStatus
+	MBE_LookupGetAlbumArtistId
 	MBE_LookupGetAlbumId
 	MBE_LookupGetArtistId
 	MBE_LookupGetRelevance
+	MBE_LookupGetTrackArtistId
 	MBE_LookupGetTrackId
 	MBE_LookupGetType
 	MBE_QuerySubject
 	MBE_QuickGetAlbumName
+	MBE_QuickGetArtistId
 	MBE_QuickGetArtistName
+	MBE_QuickGetArtistSortName
 	MBE_QuickGetTrackDuration
 	MBE_QuickGetTrackId
 	MBE_QuickGetTrackName
 	MBE_QuickGetTrackNum
+	MBE_ReleaseGetCountry
+	MBE_ReleaseGetDate
 	MBE_TOCGetCDIndexId
 	MBE_TOCGetFirstTrack
 	MBE_TOCGetLastTrack
@@ -73,6 +81,15 @@ our %EXPORT_TAGS = ( 'all' => [ qw(
 	MBE_TrackGetTrackId
 	MBE_TrackGetTrackName
 	MBE_TrackGetTrackNum
+	MBE_GetRelationshipType
+	MBE_GetRelationshipDirection
+	MBE_GetRelationshipArtistId
+	MBE_GetRelationshipArtistName
+	MBE_GetRelationshipAlbumId
+	MBE_GetRelationshipAlbumName
+	MBE_GetRelationshipTrackId
+	MBE_GetRelationshipTrackName
+	MBE_GetRelationshipURL
 	MBI_VARIOUS_ARTIST_ID
 	MBQ_AssociateCD
 	MBQ_Authenticate
@@ -92,15 +109,20 @@ our %EXPORT_TAGS = ( 'all' => [ qw(
 	MBQ_SubmitTrack
 	MBQ_SubmitTrackTRMId
 	MBQ_TrackInfoFromTRMId
+	MBQ_GetArtistRelationsById
+	MBQ_GetAlbumRelationsById
+	MBQ_GetTrackRelationsById
 	MBS_Back
 	MBS_Rewind
 	MBS_SelectAlbum
 	MBS_SelectArtist
+	MBS_SelectRelationship
 	MBS_SelectCdindexid
 	MBS_SelectLookupResult
 	MBS_SelectLookupResultAlbum
 	MBS_SelectLookupResultArtist
 	MBS_SelectLookupResultTrack
+	MBS_SelectReleaseDate
 	MBS_SelectTrack
 	MBS_SelectTrackAlbum
 	MBS_SelectTrackArtist
@@ -111,7 +133,7 @@ our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 
 our @EXPORT = qw();
 
-our $VERSION = do { my @r = (q$Revision: 1.6 $ =~ /\d+/g); $r[0]--;sprintf "%d."."%02d" x $#r, @r }; # must be all one line, for MakeMaker  
+our $VERSION = do { my @r = (q$Revision: 1.10 $ =~ /\d+/g); $r[0]--;sprintf "%d."."%02d" x $#r, @r }; # must be all one line, for MakeMaker  
 
 sub AUTOLOAD {
     # This AUTOLOAD is used to 'autoload' constants from the constant()
@@ -192,6 +214,10 @@ Return the release status of the currently selected Album.
 
 Return the release type of the currently selected Album.
 
+=item MBE_AlbumGetAmazonAsin
+
+Return the Amazon.com ASIN for the currently selected Album.
+
 =item MBE_AlbumGetArtistId
 
 Return the artist Id of the nth track in the album. Requires a 
@@ -211,6 +237,10 @@ Requires a track index ordinal. 1 for the first track, etc...
 
 Return the number of cdindexds returned in this query.
 
+=item  MBE_AlbumGetNumReleaseDates
+
+Return the number of release dates for the currently selected Album
+
 =item  MBE_AlbumGetNumTracks
 
 Return the mumber of tracks in the currently selected Album
@@ -305,9 +335,13 @@ Values for this include OK or fuzzy. Fuzzy is
 returned when the server made a fuzzy match 
 somewhere while handling the query. 
 
+=item  MBE_LookupGetAlbumArtistId
+
+Return the artist id associated with the album of the lookup result.
+
 =item  MBE_LookupGetAlbumId
 
-Return the artist id of the lookup result.
+Return the album id of the lookup result.
 
 =item  MBE_LookupGetArtistId
 
@@ -317,6 +351,10 @@ Return the artist id of the lookup result.
 
 Return the relevance of the lookup result.
 
+=item  MBE_LookupGetTrackArtistId
+
+Return the artist id associated with the track of the lookup result.
+
 =item  MBE_LookupGetTrackId
 
 Return the track id of the lookup result.
@@ -333,10 +371,18 @@ Internal use only.
 
 Return the name of the album.
 
+=item  MBE_QuickGetArtistId
+
+Return the id of the artist.
+
 =item  MBE_QuickGetArtistName
 
 Return the name of the artist.
 
+=item  MBE_QuickGetArtistSortName
+
+Return the sort name of the artist.
+
 =item  MBE_QuickGetTrackDuration
 
 Return the track duration.
@@ -353,6 +399,14 @@ Return the name of the track.
 
 Return the number of the track.
 
+=item  MBE_ReleaseGetCountry
+
+Return the country in which the album was released
+
+=item  MBE_ReleaseGetDate
+
+Return the date the album was released
+
 =item  MBE_TOCGetCDIndexId
 
 Return the CDIndex ID from the table of contents from the CD.
@@ -408,6 +462,46 @@ Return the name of the currently selected track.
 
 Return the track number in the currently selected track.
 
+=item  MBE_GetRelationshipType
+
+Get the type of an advanced relationships ilnk. Pleaes note that
+these relatnship types can change over time!
+
+=item  MBE_GetRelationshipDirection
+
+Get the direction of a link between two like entities. This
+data element will only be present for links between like types
+(eg artist-artist links) and IFF the link direction is reversed of what the
+RDF implies.
+
+=item  MBE_GetRelationshipArtistId
+
+Get the artist id that this link points to.
+
+=item  MBE_GetRelationshipArtistName
+
+Get the artist name that this link points to.
+
+=item  MBE_GetRelationshipAlbumId
+
+Get the album id that this link points to.
+
+=item  MBE_GetRelationshipAlbumName
+
+Get the album name that this link points to.
+
+=item  MBE_GetRelationshipTrackId
+
+Get the track id that this link points to.
+
+=item  MBE_GetRelationshipTrackName
+
+Get the track name that this link points to.
+
+=item  MBE_GetRelationshipURL
+
+Get the URL that this link points to.
+
 =item  MBI_VARIOUS_ARTIST_ID
 
 The MusicBrainz artist id used to indicate that an 
@@ -543,6 +637,18 @@ function will return more than on track.
 The user (or tagging app) must decide 
 which track information is correct.
 
+=item  MBQ_GetArtistRelationsById
+
+Retrieve an artistList with advanced relationships from a given artist id
+
+=item  MBQ_GetAlbumRelationsById
+
+Retrieve an albumList with advanced relationships from a given album id
+
+=item  MBQ_GetTrackRelationsById
+
+Retrieve a trackList with advanced relationships from a give track id
+
 =item  MBS_Back
 
 Use this query to change the current 
@@ -600,6 +706,11 @@ Use this Select Query to select the track
 from a lookup result. This select will be 
 used in conjunction with MBQ_FileLookup.
 
+=item  MBS_SelectReleaseDate
+
+Use this Select Query to select a Release 
+date/country from the list.
+
 =item  MBS_SelectTrack
 
 Use this Select Query to select a track 
@@ -629,6 +740,11 @@ extract data after the select.
 Use this Select Query to select a 
 trmid from the list.
 
+=item  MBS_SelectRelationship
+
+Use this Select Query to select a relationship from a list 
+advanced relationships. 
+
 =back
 
 
@@ -636,7 +752,7 @@ trmid from the list.
 
 MusicBrainz::Client
 
-http://www.musicbrainz.org/docs/mb_client/queries_h.html
+http://www.musicbrainz.org/docs/mb_client/queries_8h.html
 
 =head1 AUTHOR
 
@@ -644,7 +760,7 @@ Sander van Zoest, E<lt>svanzoest@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2003 by Alexander van Zoest
+Copyright 2003-2005 by Alexander van Zoest
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself. 
